@@ -3,7 +3,7 @@
 
 # The MIT License (MIT)
 
-# Copyright (c) 2014 CNRS
+# Copyright (c) 2014-2019 CNRS
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -39,14 +39,15 @@ PYANNOTE_LABEL = 'label'
 PYANNOTE_SCORE = 'score'
 PYANNOTE_IDENTITY = 'identity'
 
-from .time import T, TStart, TEnd
 from .segment import Segment, SlidingWindow
 from .timeline import Timeline
-from .annotation import Annotation, Unknown
-from .transcription import Transcription
-from .scores import Scores
+from .annotation import Annotation
+from .feature import SlidingWindowFeature
 
 try:
     from .notebook import notebook
 except ImportError as e:
     pass
+
+Segment.set_precision()
+
